@@ -104,7 +104,7 @@ class HttpClientTest(testtools.TestCase):
             headers={'X-Region-Name': 'RegionOne',
                      'User-Agent': 'python-glareclient'})
 
-    def test_http_json_request(self, mock_request):
+    def test_http_process_request(self, mock_request):
         # Record a 200
         mock_request.return_value = \
             fakes.FakeHTTPResponse(
@@ -112,19 +112,17 @@ class HttpClientTest(testtools.TestCase):
                 {'content-type': 'application/json'},
                 '{}')
         client = http.HTTPClient('http://example.com:9494')
-        resp, body = client.json_request('', 'GET')
+        resp, body = client.process_request('', 'GET')
         self.assertEqual(200, resp.status_code)
         self.assertEqual({}, body)
 
         mock_request.assert_called_once_with(
             'GET', 'http://example.com:9494',
             allow_redirects=False,
-            stream=False,
-            data=None,
-            headers={'Content-Type': 'application/json',
-                     'User-Agent': 'python-glareclient'})
+            headers={'User-Agent': 'python-glareclient'})
 
-    def test_http_json_request_argument_passed_to_requests(self, mock_request):
+    def test_http_process_request_argument_passed_to_requests(
+            self, mock_request):
         """Check that we have sent the proper arguments to requests."""
         # Record a 200
         mock_request.return_value = \
@@ -138,7 +136,7 @@ class HttpClientTest(testtools.TestCase):
         client.cert_file = 'RANDOM_CERT_FILE'
         client.key_file = 'RANDOM_KEY_FILE'
         client.auth_url = 'http://AUTH_URL'
-        resp, body = client.json_request('', 'GET', data='text')
+        resp, body = client.process_request('', 'GET', data='text')
         self.assertEqual(200, resp.status_code)
         self.assertEqual({}, body)
 
@@ -148,12 +146,10 @@ class HttpClientTest(testtools.TestCase):
             cert=('RANDOM_CERT_FILE', 'RANDOM_KEY_FILE'),
             verify=True,
             data='text',
-            stream=False,
-            headers={'Content-Type': 'application/json',
-                     'X-Auth-Url': 'http://AUTH_URL',
+            headers={'X-Auth-Url': 'http://AUTH_URL',
                      'User-Agent': 'python-glareclient'})
 
-    def test_http_json_request_w_req_body(self, mock_request):
+    def test_http_process_request_w_req_body(self, mock_request):
         # Record a 200
         mock_request.return_value = \
             fakes.FakeHTTPResponse(
@@ -162,18 +158,17 @@ class HttpClientTest(testtools.TestCase):
                 '{}')
 
         client = http.HTTPClient('http://example.com:9494')
-        resp, body = client.json_request('', 'GET', data='test-body')
+        resp, body = client.process_request('', 'GET', data='test-body')
         self.assertEqual(200, resp.status_code)
         self.assertEqual({}, body)
         mock_request.assert_called_once_with(
             'GET', 'http://example.com:9494',
             data='test-body',
             allow_redirects=False,
-            stream=False,
-            headers={'Content-Type': 'application/json',
-                     'User-Agent': 'python-glareclient'})
+            headers={'User-Agent': 'python-glareclient'})
 
-    def test_http_json_request_non_json_resp_cont_type(self, mock_request):
+    def test_http_process_request_non_json_resp_cont_type(
+            self, mock_request):
         # Record a 200
         mock_request.return_value = \
             fakes.FakeHTTPResponse(
@@ -182,16 +177,14 @@ class HttpClientTest(testtools.TestCase):
                 '{}')
 
         client = http.HTTPClient('http://example.com:9494')
-        resp, body = client.json_request('', 'GET', data='test-data')
+        resp, body = client.process_request('', 'GET', data='test-data')
         self.assertEqual(200, resp.status_code)
         mock_request.assert_called_once_with(
             'GET', 'http://example.com:9494', data='test-data',
             allow_redirects=False,
-            stream=False,
-            headers={'Content-Type': 'application/json',
-                     'User-Agent': 'python-glareclient'})
+            headers={'User-Agent': 'python-glareclient'})
 
-    def test_http_json_request_invalid_json(self, mock_request):
+    def test_http_process_request_invalid_json(self, mock_request):
         # Record a 200
         mock_request.return_value = \
             fakes.FakeHTTPResponse(
@@ -200,16 +193,13 @@ class HttpClientTest(testtools.TestCase):
                 'invalid-json')
 
         client = http.HTTPClient('http://example.com:9494')
-        resp, body = client.json_request('', 'GET')
+        resp, body = client.process_request('', 'GET')
         self.assertEqual(200, resp.status_code)
         self.assertIsNone(body)
         mock_request.assert_called_once_with(
             'GET', 'http://example.com:9494',
             allow_redirects=False,
-            stream=False,
-            data=None,
-            headers={'Content-Type': 'application/json',
-                     'User-Agent': 'python-glareclient'})
+            headers={'User-Agent': 'python-glareclient'})
 
     def test_http_manual_redirect_delete(self, mock_request):
         mock_request.side_effect = [
@@ -223,22 +213,16 @@ class HttpClientTest(testtools.TestCase):
                 '{}')]
 
         client = http.HTTPClient('http://example.com:9494/foo')
-        resp, body = client.json_request('', 'DELETE')
+        resp, body = client.process_request('', 'DELETE')
 
         self.assertEqual(200, resp.status_code)
         mock_request.assert_has_calls([
             mock.call('DELETE', 'http://example.com:9494/foo',
                       allow_redirects=False,
-                      stream=False,
-                      data=None,
-                      headers={'Content-Type': 'application/json',
-                               'User-Agent': 'python-glareclient'}),
+                      headers={'User-Agent': 'python-glareclient'}),
             mock.call('DELETE', 'http://example.com:9494/foo/bar',
                       allow_redirects=False,
-                      stream=False,
-                      data=None,
-                      headers={'Content-Type': 'application/json',
-                               'User-Agent': 'python-glareclient'})
+                      headers={'User-Agent': 'python-glareclient'})
         ])
 
     def test_http_manual_redirect_post(self, mock_request):
@@ -253,22 +237,18 @@ class HttpClientTest(testtools.TestCase):
                 '{}')]
 
         client = http.HTTPClient('http://example.com:9494/foo')
-        resp, body = client.json_request('', 'POST')
+        resp, body = client.process_request('', 'POST', json={})
 
         self.assertEqual(200, resp.status_code)
         mock_request.assert_has_calls([
             mock.call('POST', 'http://example.com:9494/foo',
                       allow_redirects=False,
-                      stream=False,
-                      data=None,
-                      headers={'Content-Type': 'application/json',
-                               'User-Agent': 'python-glareclient'}),
+                      headers={'User-Agent': 'python-glareclient'},
+                      json={}),
             mock.call('POST', 'http://example.com:9494/foo/bar',
                       allow_redirects=False,
-                      stream=False,
-                      data=None,
-                      headers={'Content-Type': 'application/json',
-                               'User-Agent': 'python-glareclient'})
+                      headers={'User-Agent': 'python-glareclient'},
+                      json={})
         ])
 
     def test_http_manual_redirect_put(self, mock_request):
@@ -283,22 +263,18 @@ class HttpClientTest(testtools.TestCase):
                 '{}')]
 
         client = http.HTTPClient('http://example.com:9494/foo')
-        resp, body = client.json_request('', 'PUT')
+        resp, body = client.process_request('', 'PUT', json={})
 
         self.assertEqual(200, resp.status_code)
         mock_request.assert_has_calls([
             mock.call('PUT', 'http://example.com:9494/foo',
                       allow_redirects=False,
-                      stream=False,
-                      data=None,
-                      headers={'Content-Type': 'application/json',
-                               'User-Agent': 'python-glareclient'}),
+                      headers={'User-Agent': 'python-glareclient'},
+                      json={}),
             mock.call('PUT', 'http://example.com:9494/foo/bar',
                       allow_redirects=False,
-                      stream=False,
-                      data=None,
-                      headers={'Content-Type': 'application/json',
-                               'User-Agent': 'python-glareclient'})
+                      headers={'User-Agent': 'python-glareclient'},
+                      json={})
         ])
 
     def test_http_manual_redirect_prohibited(self, mock_request):
@@ -309,14 +285,11 @@ class HttpClientTest(testtools.TestCase):
                 '')
         client = http.HTTPClient('http://example.com:9494/foo')
         self.assertRaises(exc.InvalidEndpoint,
-                          client.json_request, '', 'DELETE')
+                          client.process_request, '', 'DELETE')
         mock_request.assert_called_once_with(
             'DELETE', 'http://example.com:9494/foo',
             allow_redirects=False,
-            stream=False,
-            data=None,
-            headers={'Content-Type': 'application/json',
-                     'User-Agent': 'python-glareclient'})
+            headers={'User-Agent': 'python-glareclient'})
 
     def test_http_manual_redirect_error_without_location(self, mock_request):
         mock_request.return_value = \
@@ -326,16 +299,13 @@ class HttpClientTest(testtools.TestCase):
                 '')
         client = http.HTTPClient('http://example.com:9494/foo')
         self.assertRaises(exc.InvalidEndpoint,
-                          client.json_request, '', 'DELETE')
+                          client.process_request, '', 'DELETE')
         mock_request.assert_called_once_with(
             'DELETE', 'http://example.com:9494/foo',
             allow_redirects=False,
-            stream=False,
-            data=None,
-            headers={'Content-Type': 'application/json',
-                     'User-Agent': 'python-glareclient'})
+            headers={'User-Agent': 'python-glareclient'})
 
-    def test_http_json_request_redirect(self, mock_request):
+    def test_http_process_request_redirect(self, mock_request):
         # Record the 302
         mock_request.side_effect = [
             fakes.FakeHTTPResponse(
@@ -344,56 +314,48 @@ class HttpClientTest(testtools.TestCase):
                 ''),
             fakes.FakeHTTPResponse(
                 200, 'OK',
-                {'content-type': 'application/json'},
+                {},
                 '{}')]
 
         client = http.HTTPClient('http://example.com:9494')
-        resp, body = client.json_request('', 'GET')
+        resp, body = client.process_request('', 'GET')
         self.assertEqual(200, resp.status_code)
         self.assertEqual({}, body)
 
         mock_request.assert_has_calls([
             mock.call('GET', 'http://example.com:9494',
                       allow_redirects=False,
-                      stream=False,
-                      data=None,
-                      headers={'Content-Type': 'application/json',
-                               'User-Agent': 'python-glareclient'}),
+                      headers={'User-Agent': 'python-glareclient'}),
             mock.call('GET', 'http://example.com:9494',
                       allow_redirects=False,
-                      stream=False,
-                      data=None,
-                      headers={'Content-Type': 'application/json',
-                               'User-Agent': 'python-glareclient'})
+                      headers={'User-Agent': 'python-glareclient'})
         ])
 
-    def test_http_404_json_request(self, mock_request):
+    def test_http_404_process_request(self, mock_request):
         mock_request.return_value = \
             fakes.FakeHTTPResponse(
                 404, 'Not Found', {'content-type': 'application/json'},
                 '{}')
 
         client = http.HTTPClient('http://example.com:9494')
-        e = self.assertRaises(exc.HTTPNotFound, client.json_request, '', 'GET')
+        e = self.assertRaises(exc.HTTPNotFound, client.process_request,
+                              '', 'GET')
         # Assert that the raised exception can be converted to string
         self.assertIsNotNone(str(e))
         # Record a 404
         mock_request.assert_called_once_with(
             'GET', 'http://example.com:9494',
             allow_redirects=False,
-            stream=False,
-            data=None,
-            headers={'Content-Type': 'application/json',
-                     'User-Agent': 'python-glareclient'})
+            headers={'User-Agent': 'python-glareclient'})
 
-    def test_http_300_json_request(self, mock_request):
+    def test_http_300_process_request(self, mock_request):
         mock_request.return_value = \
             fakes.FakeHTTPResponse(
                 300, 'OK', {'content-type': 'application/json'},
                 '{}')
         client = http.HTTPClient('http://example.com:9494')
         e = self.assertRaises(
-            exc.HTTPMultipleChoices, client.json_request, '', 'GET')
+            exc.HTTPMultipleChoices, client.process_request, '', 'GET')
         # Assert that the raised exception can be converted to string
         self.assertIsNotNone(str(e))
 
@@ -401,12 +363,9 @@ class HttpClientTest(testtools.TestCase):
         mock_request.assert_called_once_with(
             'GET', 'http://example.com:9494',
             allow_redirects=False,
-            stream=False,
-            data=None,
-            headers={'Content-Type': 'application/json',
-                     'User-Agent': 'python-glareclient'})
+            headers={'User-Agent': 'python-glareclient'})
 
-    def test_fake_json_request(self, mock_request):
+    def test_fake_process_request(self, mock_request):
         headers = {'User-Agent': 'python-glareclient'}
         mock_request.side_effect = [socket.gaierror]
 
@@ -447,16 +406,13 @@ class HttpClientTest(testtools.TestCase):
                 '{}')
 
         client = http.HTTPClient('http://example.com:9494', timeout='123')
-        resp, body = client.json_request('', 'GET')
+        resp, body = client.process_request('', 'GET')
         self.assertEqual(200, resp.status_code)
         self.assertEqual({}, body)
         mock_request.assert_called_once_with(
             'GET', 'http://example.com:9494',
             allow_redirects=False,
-            stream=False,
-            data=None,
-            headers={'Content-Type': 'application/json',
-                     'User-Agent': 'python-glareclient'},
+            headers={'User-Agent': 'python-glareclient'},
             timeout=float(123))
 
     def test_get_system_ca_file(self, mock_request):
